<?php
namespace Modules\Cotacao\Modules\Pedido\Services;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource;
use Teknisa\Model\Suprimentos\Entities\Prmarcpedcol;
use Teknisa\Model\Suprimentos\Entities\Itempedcol;
use Teknisa\Model\Suprimentos\Entities\Pedcolgeral;
use Teknisa\Model\Geral\Entities\Lista;
use Util\SupUtilities;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class ControlePedidoColetaAceiteService {

    protected $entityManager;
    protected $environment;
    protected $dataSourceManager;
    protected $newCode;
    protected $smtpUtil;
    protected $supUtilities;
    protected $fileServerURL;
    protected $crudService;

    public function __construct(EntityManager $entityManager, $environment, DataSource\Manager $dataSourceManager, $newCode, $smtpUtil, SupUtilities $supUtilities, $fileServerURL, $crudService)
    {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode = $newCode;
        $this->smtpUtil = $smtpUtil;
        $this->supUtilities = $supUtilities;
        $this->fileServerURL = $fileServerURL;
        $this->crudService = $crudService;
    }

    public function iniciaTransacao(){
        $this->entityManager->beginTransaction();
    }

    public function commit(){
        $this->entityManager->commit();
    }

    public function flush(){
        $this->entityManager->flush();
    }

    public function rollback(){
        $this->entityManager->rollback();
    }
    
    public function validatePassword($operador, $password) 
    {
		$dataSourceName = 'operador';
		$conditions = array(
			array(
				'columnName' => 'CDOPERADOR',
				'operator' => '=',
				"value" => $operador
			)
		);

		$dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
		
		if (md5($password) != $dataSet[0]['CDSENHAOPERWEB']) {
			throw new \Exception("SENHA_INVALIDA", 1);
		} else {
		    return true;
		}
	}
	
	public function returnParamTermoAceite($cdforneced) 
	{
	    try {
        
            $query = "SELECT IDUTLCTRLTERMO FROM FORNECEDOR WHERE CDFORNECED = :CDFORNECED AND NRORG = :NRORG";
    
            $params = [
                "CDFORNECED" => $cdforneced,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
    
            $std = $this->entityManager->getConnection()->prepare($query);
            $std->execute($params);
            return $std->fetchAll()[0]['IDUTLCTRLTERMO'];
	    } catch (\Exception $e){
            throw $e;
        }
    }
	
	public function returnIdAceite($row){
	    $query = "SELECT IDACEITE FROM ACEITEPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDOPERADOR = :CDOPERADOR AND NRORG = :NRORG AND IDATIVO = 'S' ORDER BY DTACEITE DESC";
        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDOPERADOR" => $row['CDOPERLANC'],
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        $idAceite = $std->fetchAll();
        if(!empty($idAceite)){
            return $idAceite[0]['IDACEITE'];
        }else{
            return false;
        }
	}
	
	public function returnNextOperAceitePedCol($row){
        $query = "SELECT A.CDOPERADOR, O.NMOPERADOR FROM ACEITEPEDCOL A , OPERADOR O WHERE A.CDFILIAL = :CDFILIAL AND A.NRPEDIDOCOL = :NRPEDIDOCOL AND A.NRORG = :NRORG AND A.IDACEITE = 'N' AND A.CDOPERADOR = O.CDOPERADOR AND A.IDATIVO = 'S'";

        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        $nextOperPending = $std->fetchAll();
        if(!empty($nextOperPending)){
            return $nextOperPending;
	    }else{
	        return false;
	    }
    }
    
    public function returnExistsOperAceitePedCol($row){
        $query = "SELECT * FROM ACEITEPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NORG";

        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        return $std->fetchAll();
    }
	
	public function returnNextOperGereComp($row){
	    $query = "SELECT MIN(G.NRORDACEITEPEDCOL) AS ORDEMACEITE, G.CDOPERGERE, O.NMOPERADOR, O.DSEMAILOPER FROM GERECOMP G, OPERADOR O WHERE G.CDOPERCOMP =:CDOPERADOR AND O.CDOPERADOR = G.CDOPERGERE AND G.NRORDACEITEPEDCOL = ( SELECT MIN(G.NRORDACEITEPEDCOL) AS ORDEMACEITE FROM GERECOMP G WHERE G.CDOPERCOMP =:CDOPERADOR AND G.NRORDACEITEPEDCOL IS NOT NULL AND NOT EXISTS ( SELECT 1 FROM ACEITEPEDCOL WHERE NRPEDIDOCOL =:NRPEDIDOCOL AND CDOPERADOR = G.CDOPERGERE AND IDATIVO = 'S' ) ) GROUP BY CDOPERGERE, NMOPERADOR, DSEMAILOPER";

        $params = [
            "CDOPERADOR" => $row['COMPRADOR'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL']
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        return $std->fetchAll();
	}
	
	public function insertNextOperAceitePedCol($row, $operador) {
        $query = "INSERT INTO ACEITEPEDCOL (CDFILIAL, NRPEDIDOCOL, CDOPERADOR, IDACEITE, NRORG, DTACEITE) SELECT :CDFILIAL, :NRPEDIDOCOL, :CDOPERADOR, :IDACEITE, :NRORG, SYSDATE FROM DUAL WHERE NOT EXISTS(SELECT 1 FROM ACEITEPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDOPERADOR = :CDOPERADOR AND IDACEITE = :IDACEITE AND NRORG = :NRORG AND IDATIVO = 'S')";

        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDOPERADOR" => $operador,
            "IDACEITE" => 'N',
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
    }
    
	public function updateAceitePedCol($row, $operador) {
        $query = "UPDATE ACEITEPEDCOL SET IDACEITE = 'S', DTACEITE = SYSDATE WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDOPERADOR = :CDOPERADOR AND NRORG = :NRORG AND IDATIVO = 'S'";

        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDOPERADOR" => $operador,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
    }
	
	
    
    public function updateStatusPedCol($row, $status){
        $params = [
            "IDSITUPEDCOL" => $status,
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDFILIAL" => $row['CDFILIAL'],
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        $query = "UPDATE PEDCOLGERAL SET IDSITUPEDCOLETA = :IDSITUPEDCOL , IDRENEGOCIAPCOL = 'S' WHERE CDFILIAL =:CDFILIAL AND NRPEDIDOCOL =:NRPEDIDOCOL AND NRORG =:NRORG";
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        
        $query1 = "UPDATE PEDCOLETA SET IDSITUPEDCOL = :IDSITUPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";
        $stmt = $this->entityManager->getConnection()->prepare($query1);
        $stmt->execute($params);
    }
    
    public function updateAceitePedColRecusa($row, $operador, $justificativa){
        $query = "UPDATE ACEITEPEDCOL SET IDATIVO = 'N' WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG AND CDOPERADOR <> :CDOPERADOR";
        $query2 = "UPDATE ACEITEPEDCOL SET IDACEITE = 'R', DSJUSTIFICA = :DSJUSTIFICA WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDOPERADOR = :CDOPERADOR AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDOPERADOR" => $operador,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        
        $params2 = [
            "DSJUSTIFICA" => $justificativa,
            "CDFILIAL" => $row['CDFILIAL'],
            "NRPEDIDOCOL" => $row['NRPEDIDOCOL'],
            "CDOPERADOR" => $operador,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        
        $std2 = $this->entityManager->getConnection()->prepare($query2);
        $std2->execute($params2);
    }
    
    public function returnDsEmailOper($cdoperlanc){
        $query = "SELECT DSEMAILOPER FROM OPERADOR WHERE CDOPERADOR = :CDOPERADOR";

        $params = [
            "CDOPERADOR" => $cdoperlanc
        ];
        
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        return $std->fetchAll()[0]['DSEMAILOPER'];

    }
    
        public function selectMsgEnvEmail($funcionalidade) {
        
        $query = "SELECT DSSUBJECT,DSBODY FROM MENSAGEMPADRAOEMAIL WHERE IDOPERACAO = :P_IDOPERACAO AND NRORG = :P_NRORG AND IDATIVO = 'S'";

        $params = [
            "P_IDOPERACAO" => $funcionalidade,
            "P_NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        return $std->fetchAll();
    }
    
}